@@ -9,9 +9,7 @@ Do not use this class directly if you can use a child class with more functional
 #IMPORT MODULES
 import numpy as np
 from geomapi.nodes import Node
-import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
-
+import geomapi.utils.geometryutils as gmu
 import open3d as o3d 
 from rdflib import Graph, URIRef
 
@@ -81,7 +79,7 @@ class GeometryNode (Node):
             self._cartesianBounds=np.reshape(value,6)
         except:
             try: #orientedBounds
-                box=gt.get_oriented_bounding_box(value)
+                box=gmu.get_oriented_bounding_box(value)
                 min=box.get_min_bound()
                 max=box.get_max_bound()
                 self._cartesianBounds=np.array([min[0],max[0],min[1],max[1],min[2],max[2]])
@@ -92,13 +90,13 @@ class GeometryNode (Node):
                     self._cartesianBounds=np.array([min[0],max[0],min[1],max[1],min[2],max[2]])
                 except:
                     try: #Vector3dVector
-                        box=gt.get_oriented_bounding_box(np.asarray(value))
+                        box=gmu.get_oriented_bounding_box(np.asarray(value))
                         min=box.get_min_bound()
                         max=box.get_max_bound()
                         self._cartesianBounds=np.array([min[0],max[0],min[1],max[1],min[2],max[2]])
                     except:
                         try:#resource
-                            self._cartesianBounds=gt.get_cartesian_bounds(self._resource)
+                            self._cartesianBounds=gmu.get_cartesian_bounds(self._resource)
                         except:
                             raise ValueError('Input must be cartesianBounds (np.array [6x1]): [xMin,xMax,yMin,yMax,zMin,zMax], list like object, orientedBounds (np.Array(8x3)), or Open3D Bounding Box.')
 
@@ -204,7 +202,7 @@ class GeometryNode (Node):
                 resource =  o3d.io.read_point_cloud(self.path)
                 self._resource  =resource
             elif self.path.endswith('e57'):
-                self._resource = gt.e57path_to_pcd(self.path) 
+                self._resource = gmu.e57path_to_pcd(self.path) 
         return self._resource  
 
     def get_oriented_bounding_box(self)->o3d.geometry.OrientedBoundingBox:
@@ -222,13 +220,13 @@ class GeometryNode (Node):
         if self._orientedBoundingBox is not None:
             pass
         elif self._orientedBounds is not None:
-            self._orientedBoundingBox=gt.get_oriented_bounding_box(self._orientedBounds)
+            self._orientedBoundingBox=gmu.get_oriented_bounding_box(self._orientedBounds)
         elif self.cartesianBounds is not None:
-            self._orientedBoundingBox=gt.get_oriented_bounding_box(self._cartesianBounds)   
+            self._orientedBoundingBox=gmu.get_oriented_bounding_box(self._cartesianBounds)   
         elif self._cartesianTransform is not None:
                 box=o3d.geometry.TriangleMesh.create_box(width=1.0, height=1.0, depth=1.0)
                 boundingbox= box.get_oriented_bounding_box()
-                translation=gt.get_translation(self._cartesianTransform)
+                translation=gmu.get_translation(self._cartesianTransform)
                 self._orientedBoundingBox= boundingbox.translate(translation)
         elif self._resource is not None:
             try:
@@ -253,17 +251,17 @@ class GeometryNode (Node):
             self._cartesianTransform=np.reshape(value,(4,4))
         except:
             try: #np.ndarray or Vector3dVector (1x3)  
-                self._cartesianTransform=gt.get_cartesian_transform(translation=np.asarray(value))
+                self._cartesianTransform=gmu.get_cartesian_transform(translation=np.asarray(value))
             except:  
                 try: # cartesianBounds (np.ndarray (6x1))
-                    self._cartesianTransform=gt.get_cartesian_transform(cartesianBounds=np.asarray(value))
+                    self._cartesianTransform=gmu.get_cartesian_transform(cartesianBounds=np.asarray(value))
                 except:
                     try: # np.ndarray or Vector3dVector (8x3 or nx3)
                         center=np.mean(np.asarray(value),0)
-                        self._cartesianTransform=gt.get_cartesian_transform(translation=center)
+                        self._cartesianTransform=gmu.get_cartesian_transform(translation=center)
                     except:
                         try: # Open3D.geometry
-                            self._cartesianTransform=gt.get_cartesian_transform(translation=value.get_center())
+                            self._cartesianTransform=gmu.get_cartesian_transform(translation=value.get_center())
                         except:
                             raise ValueError('Input must be np.ndarray(6x1,4x4,3x1,nx3), an Open3D geometry or a list of Vector3dVector objects.')
 
@@ -283,14 +281,14 @@ class GeometryNode (Node):
         if self._cartesianTransform is not None:
             pass
         elif self._cartesianBounds is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(cartesianBounds=self._cartesianBounds)
+            self._cartesianTransform=gmu.get_cartesian_transform(cartesianBounds=self._cartesianBounds)
         elif self._orientedBounds is not None:
             center=np.mean(self._orientedBounds,0)
-            self._cartesianTransform=gt.get_cartesian_transform(translation=center)
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=center)
         elif self._orientedBoundingBox is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(translation=self._orientedBoundingBox.get_center())
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=self._orientedBoundingBox.get_center())
         elif self._resource is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(translation=self._resource.get_center())
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=self._resource.get_center())
         else:
             return None
         return self._cartesianTransform
@@ -309,12 +307,12 @@ class GeometryNode (Node):
         if self._cartesianBounds is not None:
             pass
         elif self._orientedBounds is not None:
-            box=gt.get_oriented_bounding_box(self._orientedBounds)
-            self._cartesianBounds= gt.get_cartesian_bounds(box)
+            box=gmu.get_oriented_bounding_box(self._orientedBounds)
+            self._cartesianBounds= gmu.get_cartesian_bounds(box)
         elif self._orientedBoundingBox is not None:
-            self._cartesianBounds=  gt.get_cartesian_bounds(self._orientedBoundingBox)
+            self._cartesianBounds=  gmu.get_cartesian_bounds(self._orientedBoundingBox)
         elif self._resource is not None:
-             self._cartesianBounds=  gt.get_cartesian_bounds(self._resource)
+             self._cartesianBounds=  gmu.get_cartesian_bounds(self._resource)
         else:
             return None
         return self._cartesianBounds
@@ -333,7 +331,7 @@ class GeometryNode (Node):
         if self._orientedBounds is not None:
             pass
         elif self._cartesianBounds is not None:
-            self._orientedBounds=np.asarray(gt.get_oriented_bounds(self._cartesianBounds))
+            self._orientedBounds=np.asarray(gmu.get_oriented_bounds(self._cartesianBounds))
         elif self._orientedBoundingBox is not None:
             self._orientedBounds=  np.asarray(self._orientedBoundingBox.get_box_points())
         elif self._resource is not None:
@@ -359,11 +357,11 @@ class GeometryNode (Node):
             center (np.ndarray(3x1))
         """        
         if self._cartesianBounds is not None:
-            return gt.get_translation(self._cartesianBounds)
+            return gmu.get_translation(self._cartesianBounds)
         elif self._orientedBounds is not None:
-            return gt.get_translation(self._orientedBounds)
+            return gmu.get_translation(self._orientedBounds)
         elif self._cartesianTransform is not None:
-            return gt.get_translation(self._cartesianTransform)
+            return gmu.get_translation(self._cartesianTransform)
         elif self._orientedBoundingBox is not None:
             return self._orientedBoundingBox.get_center()
         elif self._resource is not None:
