@@ -25,7 +25,7 @@ from scipy.spatial.transform import Rotation as R
 #IMPORT MODULES
 from geomapi.nodes import Node
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 import geomapi.utils.imageutils as it
 
 
@@ -397,10 +397,10 @@ class ImageNode(Node):
         if self.cartesianTransform is not None:
             radius=35/(focalLength35mm*2)*depth        
             mesh= o3d.geometry.TriangleMesh.create_cone(radius=radius, height=depth, resolution=20, split=1)
-            rotation=gt.get_rotation_matrix(self.cartesianTransform)
+            rotation=gmu.get_rotation_matrix(self.cartesianTransform)
             r=R.from_matrix(rotation)
             rz=R.from_euler('xyz' ,[0, 0, 0], degrees=True)
-            t=gt.get_translation(self.cartesianTransform)
+            t=gmu.get_translation(self.cartesianTransform)
             mesh=mesh.translate(t)
             r=rz*r
             # t2=r.as_matrix() * np.array([[1],[0],[0]]) *depth
@@ -427,7 +427,7 @@ class ImageNode(Node):
         """
         pinholeCamera=self.get_pinhole_camera_parameters(downsampling)
         if pinholeCamera is not None:
-            return gt.generate_virtual_image(geometries,pinholeCamera)
+            return gmu.generate_virtual_image(geometries,pinholeCamera)
         else:
             return None
 
@@ -455,7 +455,7 @@ class ImageNode(Node):
         else:
             return None
 
-    def get_intrinsic_camera_parameters(self, downsampling:int=2) -> o3d.camera.PinholeCameraIntrinsic():
+    def get_intrinsic_camera_parameters(self, downsampling:int=1) -> o3d.camera.PinholeCameraIntrinsic():
         """Returns the intrinsic camera parameters based on the following attributes.
         
         Args:
@@ -483,6 +483,10 @@ class ImageNode(Node):
         pixY=height/24 #these are standard 35mm film properties
         fx=pixX*f
         fy=pixY*f
+        
+        #! f should be in px in opencv, why are these smaller? (this was important for open3D)
+        fx=f
+        fy=f
 
         if (getattr(self,'principalPointU',None) is not None and
             getattr(self,'principalPointV',None) is not None ):
@@ -614,7 +618,7 @@ class ImageNode(Node):
             if positionnode is not None:
                 translation=np.asarray(ut.string_to_list(positionnode.text))
              
-            self.cartesianTransform=gt.get_cartesian_transform(translation=translation,rotation=rotation)
+            self.cartesianTransform=gmu.get_cartesian_transform(translation=translation,rotation=rotation)
             
             coeficientnode=child.find('{http://www.capturingreality.com/ns/xcr/1.1#}DistortionCoeficients')
             if coeficientnode is not None:
@@ -654,14 +658,14 @@ class ImageNode(Node):
                 z =  child.get('z')
                 if x and y and z:
                     translation=np.array([float(x),float(y),float(z)])
-                    self.cartesianTransform= gt.get_cartesian_transform(translation=translation)
+                    self.cartesianTransform= gmu.get_cartesian_transform(translation=translation)
                 #get rotations
                 yaw =  child.get('yaw')
                 pitch =  child.get('pitch')
                 roll =  child.get('roll')
                 if yaw and pitch and roll:
-                    rotation = gt.get_rotation_matrix(np.array([float(yaw),float(pitch),float(roll)]))
-                    self.cartesianTransform=gt.get_cartesian_transform(translation=translation, rotation=rotation)
+                    rotation = gmu.get_rotation_matrix(np.array([float(yaw),float(pitch),float(roll)]))
+                    self.cartesianTransform=gmu.get_cartesian_transform(translation=translation, rotation=rotation)
                 #get accuracies
                 sxy =  child.get('sxy')
                 if sxy:
@@ -674,8 +678,9 @@ class ImageNode(Node):
             transform=xmlNode.find('transform')
             if transform is not None:
                 self.cartesianTransform=ut.string_to_list(transform.text)
-        else:
-            raise ValueError ('subject not in xml file') 
+        #! this exception breaks the code
+        # else:
+        #     raise ValueError ('subject not in xml file') 
 
     def set_cartesianTransform(self,value):
         """Set the cartesianTransform of the ImageNode from various inputs.
@@ -691,17 +696,17 @@ class ImageNode(Node):
             self._cartesianTransform=np.reshape(value,(4,4))
         except:
             try: #np.ndarray or Vector3dVector (1x3)  
-                self._cartesianTransform=gt.get_cartesian_transform(translation=np.asarray(value))
+                self._cartesianTransform=gmu.get_cartesian_transform(translation=np.asarray(value))
             except:  
                 try: # cartesianBounds (np.ndarray (6x1))
-                    self._cartesianTransform=gt.get_cartesian_transform(cartesianBounds=np.asarray(value))
+                    self._cartesianTransform=gmu.get_cartesian_transform(cartesianBounds=np.asarray(value))
                 except:
                     try: # np.ndarray or Vector3dVector (8x3 or nx3)
                         center=np.mean(np.asarray(value),0)
-                        self._cartesianTransform=gt.get_cartesian_transform(translation=center)
+                        self._cartesianTransform=gmu.get_cartesian_transform(translation=center)
                     except:
                         try: # Open3D.geometry
-                            self._cartesianTransform=gt.get_cartesian_transform(translation=value.get_center())
+                            self._cartesianTransform=gmu.get_cartesian_transform(translation=value.get_center())
                         except:
                             raise ValueError('Input must be np.ndarray(6x1,4x4,3x1,nx3), an Open3D geometry or a list of Vector3dVector objects.')
 
@@ -723,14 +728,95 @@ class ImageNode(Node):
         elif getattr(self,'cartesianTransform',None) is not None:
             self._cartesianTransform = np.reshape(self.cartesianTransform, (4,4))
         elif getattr(self,'_cartesianBounds',None) is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(cartesianBounds=self._cartesianBounds)
+            self._cartesianTransform=gmu.get_cartesian_transform(cartesianBounds=self._cartesianBounds)
         elif getattr(self,'_orientedBounds',None) is not None:
             center=np.mean(self._orientedBounds,0)
-            self._cartesianTransform=gt.get_cartesian_transform(translation=center)
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=center)
         elif getattr(self,'_orientedBoundingBox',None) is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(translation=self._orientedBoundingBox.get_center())
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=self._orientedBoundingBox.get_center())
         elif self._resource is not None:
-            self._cartesianTransform=gt.get_cartesian_transform(translation=self._resource.get_center())
+            self._cartesianTransform=gmu.get_cartesian_transform(translation=self._resource.get_center())
         else:
             return None
-        return self._cartesianTransform
\ No newline at end of file
+        return self._cartesianTransform
+    
+    def create_rays(self,imagePoints:np.array,depths:np.array=None)->o3d.core.Tensor:
+        """Generate a grid a rays from the camera location to a given set of imagePoints.\n
+                
+        **NOTE**: This function targets a subselection of imagePoints, use o3d.t.geometry.RaycastingScene.create_rays_pinhole if you want a dense raytracing for the full image.
+        
+        .. image:: ../../../docs/pics/Raycasting_1.PNG
+        
+        Args:
+            imagePoints (np.array[n,2]): imagePoints are conform uv image coordinates system. so top left is (0,0). The camera intrinsic matrix is used to map it to the proper image coordinates.\n
+
+        Returns:
+            o3d.core.Tensor (n,6): [:,0:3] is the camera center and [:,3:6] are the directions of the rays towards the imagePoints.
+        """
+        points=imagePoints
+        #validate inputs
+        assert points.shape[-1]==2        
+        points=np.reshape(points,(-1,2)) if len(points.shape) >2 else points
+            
+        f=self.focalLength35mm 
+        k=self.get_intrinsic_camera_parameters().intrinsic_matrix
+        m=self.cartesianTransform 
+        t=gmu.get_translation(m)  
+        n=points.shape[0]
+        
+        #transform pixels to image coordinates (rows are first)
+        u=+points[:,1]-self.imageWidth/2
+        v=+points[:,0]-self.imageHeight/2    
+        camera_coordinates=np.vstack((u,v,np.ones(n)))
+        
+        #transform to world coordinates
+        camera_coordinates=np.vstack((camera_coordinates[0:2,:],np.full(n, f).T,np.ones((n,1)).T))
+        world_coordinates=m @ camera_coordinates
+        world_coordinates=gmu.normalize_vectors(world_coordinates[0:3,:].T)
+  
+        if depths is not None:
+            world_coordinates=world_coordinates * depths[:, np.newaxis]
+  
+        
+        
+        #create rays [camera.center, direction(world_coordinates)]
+        rays=np.hstack((np.full((n,3), t),world_coordinates))         
+        return rays 
+    
+    # def create_rays(self,imagePoints:np.array)->o3d.core.Tensor:
+    #     """Generate a grid a rays from the camera location to a given set of imagePoints.\n
+                
+    #     **NOTE**: This function targets a subselection of imagePoints, use o3d.t.geometry.RaycastingScene.create_rays_pinhole if you want a dense raytracing for the full image.
+        
+    #     .. image:: ../../../docs/pics/Raycasting_1.PNG
+        
+    #     Args:
+    #         imagePoints (np.array[n,2]): imagePoints are conform uv image coordinates system. so top left is (0,0). The camera intrinsic matrix is used to map it to the proper image coordinates.\n
+
+    #     Returns:
+    #         o3d.core.Tensor (n,6): [:,0:3] is the camera center and [:,3:6] are the directions of the rays towards the imagePoints.
+    #     """
+    #     points=imagePoints
+    #     #validate inputs
+    #     assert points.shape[-1]==2        
+    #     points=np.reshape(points,(-1,2)) if len(points.shape) >2 else points
+            
+    #     f=self.focalLength35mm 
+    #     k=self.get_intrinsic_camera_parameters().intrinsic_matrix
+    #     m=self.cartesianTransform 
+    #     t=gmu.get_translation(m)  
+    #     n=points.shape[0]
+        
+    #     #transform pixels to image coordinates (rows are first)
+    #     u=points[:,1]-self.imageWidth/2
+    #     v=-points[:,0]+self.imageHeight/2    
+    #     camera_coordinates=np.vstack((u,v,np.ones(n)))
+        
+    #     #transform to world coordinates
+    #     camera_coordinates=np.vstack((camera_coordinates[0:2,:],np.full(n, f).T,np.ones((n,1)).T))
+    #     world_coordinates=m @ camera_coordinates
+    #     world_coordinates=gmu.normalize_vectors(world_coordinates[0:3,:].T)
+  
+    #     #create rays [camera.center, direction(world_coordinates)]
+    #     rays=np.hstack((np.full((n,3), t),world_coordinates))         
+    #     return rays 
\ No newline at end of file
