@@ -13,7 +13,7 @@ import ifcopenshell.util
 #IMPORT MODULES
 from geomapi.nodes import GeometryNode
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 
 
 class LinesetNode (GeometryNode):
@@ -135,7 +135,7 @@ class LinesetNode (GeometryNode):
                 try:
                     ifc = ifcopenshell.open(self.ifcPath)   
                     ifcElement= ifc.by_guid(self.globalId)
-                    self.mesh=gt.ifc_to_mesh(ifcElement)
+                    self.mesh=gmu.ifc_to_mesh(ifcElement)
                     return self.mesh
                 except:
                     pass
@@ -206,7 +206,7 @@ class LinesetNode (GeometryNode):
                                                     [0,0,1,center[2]],
                                                     [0,0,0,1]])
                 self.pointCount= len(self.mesh.vertices)
-                self.cartesianBounds=gt.get_cartesian_bounds(self.mesh)
+                self.cartesianBounds=gmu.get_cartesian_bounds(self.mesh)
             except:
                 pass
             return True
