@@ -7,7 +7,6 @@ Be sure to check the properties defined in those abstract classes to initialise
 
 """
 #IMPORT PACKAGES
-from pathlib import Path
 import xml.etree.ElementTree as ET
 from xmlrpc.client import Boolean 
 import open3d as o3d 
@@ -15,12 +14,12 @@ import numpy as np
 import os
 from scipy.spatial.transform import Rotation as R
 from rdflib import Graph, URIRef
-import pye57 #conda install xerces-c  =>  pip install pye57
+import pye57 
 
 #IMPORT MODULES
 from geomapi.nodes import GeometryNode
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 
 class PointCloudNode (GeometryNode):
     def __init__(self,  graph : Graph = None, 
@@ -125,7 +124,7 @@ class PointCloudNode (GeometryNode):
         if 'PointCloud' in str(type(value)) and len(value.points) >=3:
             self._resource = value
         elif 'e57' in str(type(value)):
-            self._resource=gt.e57_to_pcd(value,self.get_e57Index())
+            self._resource=gmu.e57_to_pcd(value,self.get_e57Index())
         else:
             raise ValueError('Resource must be an o3d.geometry.PointCloud with len(resource.points) >=3 or an pye57.e57.E57 instance.')
 
@@ -149,7 +148,7 @@ class PointCloudNode (GeometryNode):
                 if len(resource.points)>3:
                     self._resource  =resource
             elif self.path.endswith('e57'):
-                self._resource = gt.e57path_to_pcd(self.path, self.get_e57Index(),percentage=percentage) 
+                self._resource = gmu.e57path_to_pcd(self.path, self.get_e57Index(),percentage=percentage) 
         return self._resource  
 
     def save_resource(self, directory:str=None,extension :str = '.pcd') ->bool:
@@ -175,7 +174,7 @@ class PointCloudNode (GeometryNode):
 
         filename=ut.validate_string(self.name)
 
-        # check if already exists
+        #check if already exists
         if directory and os.path.exists(os.path.join(directory,filename + extension)):
             self.path=os.path.join(directory,filename + extension)
             return True
@@ -202,7 +201,7 @@ class PointCloudNode (GeometryNode):
 
         #write files
         if self.path.endswith('.e57'):
-            data3D=gt.get_data3d_from_pcd(self.resource)
+            data3D=gmu.get_data3d_from_pcd(self.resource)
             rotation=np.array([1,0,0,0])
             translation=np.array([0,0,0])
             with pye57.E57(self._path, mode="w") as e57_write:
@@ -240,7 +239,7 @@ class PointCloudNode (GeometryNode):
                                                 [0,0,0,1]])
 
             if getattr(self,'cartesianBounds',None) is  None:
-                self.cartesianBounds=gt.get_cartesian_bounds(self.resource)
+                self.cartesianBounds=gmu.get_cartesian_bounds(self.resource)
             if getattr(self,'orientedBoundingBox',None) is  None:
                 self.orientedBoundingBox=self.resource.get_oriented_bounding_box()
             if getattr(self,'orientedBounds',None) is  None:
@@ -284,7 +283,7 @@ class PointCloudNode (GeometryNode):
                     rotation_matrix=header.rotation_matrix
                 if getattr(header,'translation',None) is not None:
                     translation=header.translation
-                self.cartesianTransform=gt.get_cartesian_transform(rotation=rotation_matrix,translation=translation)
+                self.cartesianTransform=gmu.get_cartesian_transform(rotation=rotation_matrix,translation=translation)
             if 'name' in header.scan_fields:
                 self.name=header['name'].value()
                 string=ut.validate_string(self._name)
@@ -334,7 +333,6 @@ class PointCloudNode (GeometryNode):
         self.name=ut.get_filename(self.e57XmlPath) +'_'+str(self.e57Index)
         self.subject=self.name
         self.timestamp=ut.get_timestamp(self.e57XmlPath)
-        # self.path=self.path.replace('.xml','.e57')
         try:
             mytree = ET.parse(self.e57XmlPath)
             root = mytree.getroot()         
@@ -382,10 +380,10 @@ class PointCloudNode (GeometryNode):
                                 translationVector=np.nan_to_num(translationVector)       
                             except:
                                 translationVector=np.array([0.0,0.0,0.0])
-                        self.cartesianTransform=gt.get_cartesian_transform(rotationMatrix,translationVector)
+                        self.cartesianTransform=gmu.get_cartesian_transform(rotationMatrix,translationVector)
                     # SET POSE FROM cartesianBounds
                     elif self.cartesianBounds is not None:            
-                        self.cartesianTransform=gt.get_cartesian_transform(self.cartesianBounds)
+                        self.cartesianTransform=gmu.get_cartesian_transform(self.cartesianBounds)
 
                     pointsnode=e57xml.find('{http://www.astm.org/COMMIT/E57/2010-e57-v1.0}points')
                     if not pointsnode is None:
