@@ -1,22 +1,20 @@
 """
-SessionNode - a Python Class to govern the data and metadata of remote sensing data captured in the same epoch. \n
+SessionNode - a Python Class to govern the data and metadata of remote sensing data captured in the same epoch.
 
-This node buids upon Open3D for its geometry definitions.\n
+This node buids upon Open3D for its geometry definitions.
 This node uses LinkedNodes (ImageNodes, PointCloudNodes, etc.) to describe resources gathered in the same epoch.
-It directly inherits from Node.\n
+It directly inherits from Node.
 Be sure to check the properties defined in the above classes to initialise the Node.
 
 Goals:
-- Given a path, import all the linked images, meshes, ect... into a session class \n
-- Convert non-RDF metadata files (json, xml, ect..) to SessionsNodes and export them to RDF \n
-- get the boundingbox of the whole session \n
-- use URIRef() to reference the images, ect... \n
+- Given a path, import all the linked images, meshes, ect... into a session class
+- Convert non-RDF metadata files (json, xml, ect..) to SessionsNodes and export them to RDF
+- get the boundingbox of the whole session
+- use URIRef() to reference the images, ect...
+
 """  
-from xml.dom.minicompat import NodeList
-from rdflib import Graph, URIRef, Literal
-import rdflib
+from rdflib import Graph, URIRef
 from rdflib.namespace import RDF
-import geomapi
 from typing import List
 import open3d as o3d 
 import cv2
@@ -29,7 +27,7 @@ import concurrent.futures
 #IMPORT MODULES
 from geomapi.nodes import *
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 
 class SessionNode(GeometryNode):
 
@@ -175,7 +173,6 @@ class SessionNode(GeometryNode):
         Returns:
             self.linkedNodes (Node)
         """
-
         #validate inputs
         if(not type(resourceGraph) ==Graph): 
             raise ValueError('resourceGraph is not an RDFlib Graph')
@@ -270,8 +267,8 @@ class SessionNode(GeometryNode):
         """Serialize the session's linkedNodes
 
         Args:
-            graphPath (str,optional): defaults to linkednodesGraph.ttl in session graphPath location.
-            save (bool, optional): Defaults to False.
+            1.graphPath (str,optional): defaults to linkednodesGraph.ttl in session graphPath location.\n
+            2.save (bool, optional): Defaults to False.\n
 
         Returns:
             Graph with linkedNodes
@@ -292,11 +289,11 @@ class SessionNode(GeometryNode):
         return g  
 
     def session_to_graph(self,graphPath:str=None,save:bool=False) -> Graph:
-        """Serialize the session's linkedNodes and own metadata
+        """Serialize the session's linkedNodes and own metadata.\n
 
         Args:
-            graphPath (str,optional): defaults to combinedGraph.ttl in session graphPath location.
-            save (bool, optional): Defaults to False.
+            1.graphPath (str,optional): defaults to combinedGraph.ttl in session graphPath location.\n
+            2.save (bool, optional): Defaults to False.\n
 
         Returns:
             Graph with linkedNodes and sessionNode
@@ -381,14 +378,14 @@ class SessionNode(GeometryNode):
             return True
         return False
 
-    def resources_to_linked_nodes(self,linkedResources) -> Node:
-        """Create proper node type from a data resource
+    def resources_to_linked_nodes(self,linkedResources) -> None:
+        """Create linked Nodes from a set of data resources.\n
 
         Args:
-            resource (mesh,pcd,image,ortho,lineset,etc.): 
+            resource (List[mesh,pcd,image,ortho,lineset,etc.])
 
         Returns:
-            Node: 
+            None 
         """
         nodelist=[]
         for resource in linkedResources:
@@ -437,16 +434,16 @@ class SessionNode(GeometryNode):
                     points.extend(box.get_box_points())    
                 
             elif getattr(node,'cartesianTransform',None) is not None:
-                t=gt.get_translation(node.get_cartesian_transform())
+                t=gmu.get_translation(node.get_cartesian_transform())
                 t=np.reshape(t,(1,3))
                 p=o3d.cpu.pybind.utility.Vector3dVector(t)
                 points.extend(p)
 
         if np.asarray(points).shape[0] >=5:    
-            self.cartesianTransform=gt.get_cartesian_transform(translation=np.mean( np.asarray(points),0)) 
+            self.cartesianTransform=gmu.get_cartesian_transform(translation=np.mean( np.asarray(points),0)) 
             self.orientedBoundingBox=o3d.geometry.OrientedBoundingBox.create_from_points(points)
             self.orientedBounds=np.asarray(self.orientedBoundingBox.get_box_points())
-            self.cartesianBounds=gt.get_cartesian_bounds(o3d.geometry.AxisAlignedBoundingBox.create_from_points(points))
+            self.cartesianBounds=gmu.get_cartesian_bounds(o3d.geometry.AxisAlignedBoundingBox.create_from_points(points))
             pcd= o3d.geometry.PointCloud()
             pcd.points=points
             hull, _ =pcd.compute_convex_hull()
@@ -488,22 +485,22 @@ class SessionNode(GeometryNode):
 
         with concurrent.futures.ProcessPoolExecutor() as executor:
             # first load all data and output it as np.arrays      
-            results1=[executor.submit(gt.e57_to_arrays,e57Path=n.path,e57Index=n.e57Index,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+            results1=[executor.submit(gmu.e57_to_arrays,e57Path=n.path,e57Index=n.e57Index,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
                         if 'PointCloud' in str(type(n)) and 
                             n.resource is None and
                             n.path.endswith('.e57') and 
                             os.path.exists(n.path)]
 
-            results2=[executor.submit(gt.pcd_to_arrays,path=n.path,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+            results2=[executor.submit(gmu.pcd_to_arrays,path=n.path,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
                         if 'PointCloud' in str(type(n)) and 
                             n.resource is None and
                             n.path.endswith('.pcd') and 
                             os.path.exists(n.path)]
-            results3=[executor.submit(gt.mesh_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+            results3=[executor.submit(gmu.mesh_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
                         if ('MeshNode' in str(type(n)) or 'BIMNode' in str(type(n))) and 
                             n.resource is None and
                             os.path.exists(n.path)]
-            results4=[executor.submit(gt.img_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+            results4=[executor.submit(gmu.img_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
                         if 'ImageNode' in str(type(n)) and 
                         n.resource is None and
                         os.path.exists(n.path)]
@@ -511,14 +508,14 @@ class SessionNode(GeometryNode):
         # next, the arrays are assigned to point clouds outside the loop.
         # Note that these loops should be in parallel as they would otherwise obstruct one another.
         for r1 in concurrent.futures.as_completed(results1): 
-            resource=gt.arrays_to_pcd(r1.result())
+            resource=gmu.arrays_to_pcd(r1.result())
             self.linkedNodes[r1.result()[-1]].resource=resource
         for r2 in concurrent.futures.as_completed(results2): 
-            resource=gt.arrays_to_pcd(r2.result())
+            resource=gmu.arrays_to_pcd(r2.result())
             self.linkedNodes[r2.result()[-1]].resource=resource
         for r3 in concurrent.futures.as_completed(results3): 
             # print(len(r3.result()[0]))
-            resource=gt.arrays_to_mesh(r3.result())
+            resource=gmu.arrays_to_mesh(r3.result())
             self.linkedNodes[r3.result()[-1]].resource=resource
         for r4 in concurrent.futures.as_completed(results4): 
             self.linkedNodes[r4.result()[-1]].resource=r4.result()[0]
@@ -573,7 +570,7 @@ class SessionNode(GeometryNode):
                                                     [0,0,0,1]])
 
             if getattr(self,'cartesianBounds',None) is  None:
-                self.cartesianBounds=gt.get_cartesian_bounds(self.resource)
+                self.cartesianBounds=gmu.get_cartesian_bounds(self.resource)
             if getattr(self,'orientedBoundingBox',None) is  None:
                 self.orientedBoundingBox=self.resource.get_oriented_bounding_box()
             if getattr(self,'orientedBounds',None) is  None:
