@@ -1,8 +1,5 @@
-"""Different tools to Manage RDF data"""
+"""Different tools to Manage RDF data."""
 
-"""
-linkeddatatools - a Python library for RDF graph structuring and exchange.
-"""
 #IMPORT PACKAGES
 from dis import dis
 from lib2to3.pytree import Node
@@ -11,24 +8,22 @@ import cv2
 import open3d as o3d 
 import os 
 import re
-import pye57 #conda install xerces-c  =>  pip install pye57
+import pye57 
 import pandas as pd
-
 import xml.etree.ElementTree as ET 
 from typing import List,Tuple
 
 # import APIs
 import rdflib
-from rdflib import Graph, plugin
-from rdflib.serializer import Serializer #pip install rdflib-jsonld https://pypi.org/project/rdflib-jsonld/
 from rdflib import Graph
-from rdflib import URIRef, BNode, Literal
+from rdflib import Graph
+from rdflib import URIRef, Literal
 from rdflib.namespace import CSVW, DC, DCAT, DCTERMS, DOAP, FOAF, ODRL2, ORG, OWL, \
                            PROF, PROV, RDF, RDFS, SDO, SH, SKOS, SOSA, SSN, TIME, \
                            VOID, XMLNS, XSD
 import ifcopenshell
-import ifcopenshell.geom as geom
 import ifcopenshell.util
+import ifcopenshell.geom as geom
 from ifcopenshell.util.selector import Selector
 import multiprocessing
 import concurrent.futures
@@ -37,8 +32,7 @@ import concurrent.futures
 from geomapi.nodes import *
 from geomapi.nodes.sessionnode import create_node 
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
-
+import geomapi.utils.geometryutils as gmu
 from warnings import warn
 
 #ONTOLOGIES
@@ -46,7 +40,6 @@ loa=rdflib.Namespace('https://docplayer.net/131921614-Usibd-level-of-accuracy-lo
 ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
 
 #### NODE CREATION ####
-
 def e57xml_to_nodes(e57XmlPath :str, **kwargs) -> List[PointCloudNode]:
     """Parse XML file that is created with E57lib e57xmldump.exe.
 
@@ -113,10 +106,10 @@ def e57path_to_nodes(e57Path:str,percentage:float=1.0) ->List[PointCloudNode]:
         o3d.geometry.PointCloud
     """    
     e57 = pye57.E57(e57Path)
-    gt.e57_update_point_field(e57)
+    gmu.e57_update_point_field(e57)
     nodes=[]
     for s in range(e57.scan_count):
-        resource=gt.e57_to_pcd(e57,e57Index=s,percentage=percentage)
+        resource=gmu.e57_to_pcd(e57,e57Index=s,percentage=percentage)
         node=PointCloudNode(resource=resource,
                             path=e57Path,
                             e57Index=s,
@@ -144,15 +137,15 @@ def e57path_to_nodes_mutiprocessing(e57Path:str,percentage:float=1.0) ->List[Poi
         o3d.geometry.PointCloud
     """    
     e57 = pye57.E57(e57Path)
-    gt.e57_update_point_field(e57)
+    gmu.e57_update_point_field(e57)
 
     nodes=[]
     with concurrent.futures.ProcessPoolExecutor() as executor:
         # first load all e57 data and output it as np.arrays
-        results=[executor.submit(gt.e57_to_arrays,e57Path=e57Path,e57Index=s,percentage=percentage) for s in range(e57.scan_count)]
+        results=[executor.submit(gmu.e57_to_arrays,e57Path=e57Path,e57Index=s,percentage=percentage) for s in range(e57.scan_count)]
         # next, the arrays are assigned to point clouds outside the loop.
         for s,r in enumerate(concurrent.futures.as_completed(results)):
-            resource=gt.arrays_to_pcd(r.result())
+            resource=gmu.arrays_to_pcd(r.result())
             node=PointCloudNode(resource=resource,
                                 path=e57Path,
                                 e57Index=s,
@@ -175,7 +168,7 @@ def e57header_to_nodes(e57Path:str, **kwargs) -> List[PointCloudNode]:
 
         nodelist=[]   
         e57 = pye57.E57(e57Path)   
-        gt.e57_update_point_field(e57)
+        gmu.e57_update_point_field(e57)
 
         for idx in range(e57.scan_count):
             nodelist.append(PointCloudNode(path=e57Path,e57Index=idx, **kwargs))
@@ -467,7 +460,6 @@ def ifc_to_nodes(ifcPath:str, classes:str='.IfcBuildingElement',getResource : bo
         ifc = ifcopenshell.open(ifcPath)   
         selector = Selector()
         for ifcElement in selector.parse(ifc, classes):
-            # print(ifcElement.Name) # THIS IS TEMP
             node=BIMNode(resource=ifcElement,getResource=getResource, **kwargs)          
             node.ifcPath=ifcPath
             nodelist.append(node)
@@ -629,13 +621,13 @@ def select_k_nearest_nodes(node:Node,nodelist:List[Node],k:int=10) -> Tuple[List
 
     #get node center
     if node.get_cartesian_transform() is not None:
-        point=gt.get_translation(node.cartesianTransform)
+        point=gmu.get_translation(node.cartesianTransform)
         #create pcd from nodelist centers
         pcd = o3d.geometry.PointCloud()
         array=np.empty(shape=(len(nodelist),3))
         for idx,node in enumerate(nodelist):
             if node.get_cartesian_transform() is not None:
-                array[idx]=gt.get_translation(node.cartesianTransform)
+                array[idx]=gmu.get_translation(node.cartesianTransform)
             else:
                 array[idx]=[-10000.0,-10000.0,-10000.0]
         pcd.points = o3d.utility.Vector3dVector(array)
@@ -670,13 +662,13 @@ def select_nodes_with_centers_in_radius(node:Node,nodelist:List[Node],r:float=0.
         raise ValueError('r must be positive and non-negative.')
     #get node center
     if node.get_cartesian_transform() is not None:
-        point=gt.get_translation(node.cartesianTransform)
+        point=gmu.get_translation(node.cartesianTransform)
         #create pcd from nodelist centers
         pcd = o3d.geometry.PointCloud()
         array=np.empty(shape=(len(nodelist),3))
         for idx,node in enumerate(nodelist):
             if node.get_cartesian_transform() is not None:
-                array[idx]=gt.get_translation(node.cartesianTransform)
+                array[idx]=gmu.get_translation(node.cartesianTransform)
             else:
                 array[idx]=[-10000.0,-10000.0,-10000.0]
         pcd.points = o3d.utility.Vector3dVector(array)
@@ -713,13 +705,13 @@ def select_nodes_with_centers_in_bounding_box(node:Node,nodelist:List[Node],u:fl
     #get box source node
     if node.get_oriented_bounding_box() is not None:
         box=node.orientedBoundingBox
-        box=gt.expand_box(box,u=u,v=v,w=w)
+        box=gmu.expand_box(box,u=u,v=v,w=w)
 
         # get centers
         centers=np.empty((len(nodelist),3),dtype=float)
         for idx,node in enumerate(nodelist):
             if node.get_cartesian_transform() is not None:
-                centers[idx]=gt.get_translation(node.cartesianTransform)
+                centers[idx]=gmu.get_translation(node.cartesianTransform)
 
         #points are the centers of all the nodes
         pcd = o3d.geometry.PointCloud()
@@ -752,7 +744,7 @@ def select_nodes_with_bounding_points_in_bounding_box(node:Node,nodelist:List[No
     #get box source node
     if node.get_oriented_bounding_box() is not None:
         box=node.orientedBoundingBox
-        box=gt.expand_box(box,u=u,v=v,w=w)
+        box=gmu.expand_box(box,u=u,v=v,w=w)
 
         # get boxes nodelist
         boxes=np.empty((len(nodelist),1),dtype=o3d.geometry.OrientedBoundingBox)
@@ -760,7 +752,7 @@ def select_nodes_with_bounding_points_in_bounding_box(node:Node,nodelist:List[No
             boxes[idx]=node.get_oriented_bounding_box()
 
         # Find the nodes of which the bounding points lie in the source node box
-        idxList=gt.get_box_inliers(box,boxes)
+        idxList=gmu.get_box_inliers(box,boxes)
         selectedNodeList=[node for idx,node in enumerate(nodelist) if idx in idxList]
         if any(selectedNodeList):        
             return selectedNodeList
@@ -785,7 +777,7 @@ def select_nodes_with_intersecting_bounding_box(node:Node,nodelist:List[Node],u:
     #get box source node
     if node.get_oriented_bounding_box() is not None:
         box=node.orientedBoundingBox
-        box=gt.expand_box(box,u=u,v=v,w=w)
+        box=gmu.expand_box(box,u=u,v=v,w=w)
 
         # get boxes nodelist
         boxes=np.empty((len(nodelist),1),dtype=o3d.geometry.OrientedBoundingBox)
@@ -793,7 +785,7 @@ def select_nodes_with_intersecting_bounding_box(node:Node,nodelist:List[Node],u:
             boxes[idx]=node.get_oriented_bounding_box()
         
         # Find the nodes of which the bounding box itersects with the source node box
-        idxList=gt.get_box_intersections(box,boxes)
+        idxList=gmu.get_box_intersections(box,boxes)
         selectedNodeList=[node for idx,node in enumerate(nodelist) if idx in idxList]
         if any(selectedNodeList):        
             return selectedNodeList
@@ -827,17 +819,15 @@ def select_nodes_with_intersecting_resources(node:Node,nodelist:List[Node]) -> L
                     meshes[idx]=get_mesh_representation(testnode)
 
         # Find the nodes of which the geometry intersects with the source node box
-        idxList=gt.get_mesh_inliers(reference=mesh,sources=meshes)
+        idxList=gmu.get_mesh_inliers(reference=mesh,sources=meshes)
         print(idxList)
 
-        # idxList=gt.get_mesh_collisions_trimesh(mesh,meshes)
+        # idxList=gmu.get_mesh_collisions_trimesh(mesh,meshes)
         selectedNodeList=[node for idx,node in enumerate(nodelist) if idx in idxList]
         if any(selectedNodeList):        
             return selectedNodeList
     return None
 
-#### GRAPH CREATION #####
-
 def get_mesh_representation(node: Node)->o3d.geometry.TriangleMesh:
     """Returns the mesh representation of a node resource\n
     Returns the convex hull if it is a PointCloudNode.\n
