@@ -1,15 +1,90 @@
 
-"""Tools to asses the progress on (road) construction sites
-"""
+"""Tools to asses the progress on (road) construction sites."""
 
 import numpy as np
 import open3d as o3d
-import geomapi
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
-
+import geomapi.utils.geometryutils as gmu
 from typing import List,Tuple
+from colour import Color
+from geomapi.nodes import ImageNode
+import copy 
 
+def assign_point_cloud_information(source_cloud:o3d.geometry.PointCloud,ref_clouds:List[o3d.geometry.PointCloud],class_names:List[int]=None)->np.array:
+    ref_cloud,ref_arr=gmu.create_identity_point_cloud(ref_clouds)
+    indices,distances=gmu.compute_nearest_neighbors(np.asarray(source_cloud.points),np.asarray(ref_cloud.points))
+    index=ref_arr[indices]
+    distances=distances[:,0]
+    class_names=np.argmax(ref_arr)      if class_names is None  else class_names
+    arr=np.zeros(len(np.asarray(source_cloud.points)))
+    for ind in np.unique(index):
+        locations=np.where(index ==ind)
+        np.put(arr,locations,class_names[ind])
+    return arr
+
+def filter_img_classifcation_by_neighbors (predictions:np.array,shape: Tuple[int,int]=None,weight:float=3)->np.array:
+    """Filters an initial raster prediction based on the classification of surrounding values.\n
+    Every value is replaced by the most occuring value in the 9 surrounding raster values weighted by the initial value
+
+    Args:
+        predictions (np.array): _description_
+        shape (Tuple[int,int]): shape of the raster
+        weight (float, optional): influence of the initial value compared to neighboring values. Defaults to 3.
+
+    Returns:
+        np.array: _description_
+    """
+    #validate inputs
+    shape=predictions.shape    if not shape     else shape
+    predictions=np.reshape(predictions,shape)
+    newPredictions=predictions
+    #select most frequently occuring value in vincinity of each region (multiplied by weight for initial pixel)
+    for i in range(1,predictions.shape[0]-1):
+        for j in range(1,predictions.shape[1]-1):
+            arr=np.hstack((predictions[i-1:i+1,j-1:j+1].flatten(),np.full((weight-1),predictions[i,j])))         
+            newPredictions[i,j]=np.argmax(np.bincount(arr)) 
+    return np.reshape(newPredictions,(-1,1)).flatten()
+    
+def project_pcd_to_rgbd_images (pointClouds:List[o3d.geometry.Geometry], imgNodes:List[ImageNode], depth_scale:float=1.0,depth_max:float=15)->Tuple[List[np.array],List[np.array],List[np.array]]:
+    """Project a set of point cloud geometries given camera parameters. The given
+
+    .. image:: ../../../docs/pics/ractracing1.PNG
+
+    Args:
+        1.pointClouds (List[o3d.geometry.PointCloud]): set of o3d point clouds.\n
+        2.imgNodes (List[ImageNode]): should contain imageWidth,imageHeight,cartesianTransform and focalLength35mm\n
+        3.depth_scale (float, optional): Defaults to 1.0 (real distance).\n
+        4.depth_max (float, optional): cut off distance. Defaults to 15m.\n
+
+    Returns:
+        Tuple[List[np.array],List[np.array],List[np.array]]: colorImages,depthImages
+    """
+    #validate point clouds
+    pointClouds=ut.item_to_list(pointClouds)
+    pointClouds=gmu.join_geometries(pointClouds)
+    pcd = o3d.t.geometry.PointCloud.from_legacy(pointClouds)
+    colorImages=[]
+    depthImages=[]
+    #project color and depth from point cloud to images
+    for n in ut.item_to_list(imgNodes):
+        intrinsic=n.get_intrinsic_camera_parameters().intrinsic_matrix
+        extrinsic= np.linalg.inv(n.get_cartesian_transform()) 
+        rgbd_reproj = pcd.project_to_rgbd_image(int(n.imageWidth),
+                                        int(n.imageHeight),
+                                        intrinsic,
+                                        extrinsic,
+                                        depth_scale=depth_scale,
+                                        depth_max=depth_max)
+        # reverse order so orientation matches image
+        colorImage=np.asarray(rgbd_reproj.color.to_legacy())
+        # colorImage=colorImage[::-1,::-1]
+        depthImage=np.asarray(rgbd_reproj.depth.to_legacy())
+        # depthImage=depthImage[::-1,::-1]
+    
+        colorImages.append(colorImage)
+        depthImages.append(depthImage)
+    return colorImages,depthImages
+        
 def get_average_cartesian_transform_ortho(list):
     i=0
     sum1=0
@@ -34,80 +109,8 @@ def get_average_cartesian_transform_ortho(list):
     average3=sum3/length
 
     matrix=np.array([[1,0,0,average1],[0,1,0,average2],[0,0,1,average3],[0,0,0,1]])
-
     return matrix
 
-
-def create_visible_point_cloud_from_meshes (geometries: List[o3d.geometry.TriangleMesh], 
-                                            references:List[o3d.geometry.TriangleMesh], 
-                                            resolution:float = 0.1,
-                                            getNormals:bool=False)-> Tuple[List[o3d.geometry.PointCloud], List[float]]:
-    """Returns a set of point clouds sampled on the geometries. Each point cloud has its points filtered to not lie wihtin or collide with any of the reference geometries. As such, this method returns the **visible** parts of a set of sampled point clouds. \n
-    
-    For every point cloud, the percentage of visibility is also reported. This method takes about 50s for 1000 geometries. \n
-    \n
-    E.g. The figure shows the points of the visible point cloud that were rejected due to their proximity to the other mesh geometries.
-
-    .. image:: ../../../docs/pics/invisible_points.PNG
-
-    Args:
-        1. geometries (List[o3d.geometry.TriangleMesh]): Meshes that will be sampled up to the resolution. \n
-        2. references (List[o3d.geometry.TriangleMesh]): reference meshes that are used to spatially filter the sampled point clouds so only 'visible' points are retained. If some targget \n
-        3. resolution (float, optional): Spatial resolution to sample meshes. Defaults to 0.1m. \n
-
-    Raises:
-        ValueError: any('TriangleMesh' not in str(type(g)) for g in geometries )\n
-        ValueError: any('TriangleMesh' not in str(type(g)) for g in references )\n
-
-    Returns:
-        Tuple[List[o3d.geometry.PointCloud], List[percentages [0-1.0]]] per geometry
-    """
-    geometries=ut.item_to_list(geometries)    
-    references=ut.item_to_list(references)    
-
-    #validate geometries
-    if  any('TriangleMesh' not in str(type(g)) for g in geometries ):
-        raise ValueError('Only submit o3d.geometry.TriangleMesh objects') 
-    #validate geometries
-    if  any('TriangleMesh' not in str(type(g)) for g in references ):
-        raise ValueError('Only submit o3d.geometry.TriangleMesh objects') 
-
-    colorArray=np.random.random((len(geometries),3))
-    identityPointClouds=[]
-    percentages=[]
-
-    for i,geometry in enumerate(geometries):        
-        # create a reference scene 
-        referenceGeometries=[g for g in references if g !=geometry ]
-        reference=gt.join_geometries(referenceGeometries)
-        scene = o3d.t.geometry.RaycastingScene()
-        cpuReference = o3d.t.geometry.TriangleMesh.from_legacy(reference)
-        _ = scene.add_triangles(cpuReference)
-
-        # sample mesh (optional with normals)
-        if getNormals and not geometry.has_triangle_normals():
-            geometry.compute_triangle_normals()
-        area=geometry.get_surface_area()
-        count=int(area/(resolution*resolution))
-        pcd=geometry.sample_points_uniformly(number_of_points=10*count,use_triangle_normal=getNormals)
-        pcd=pcd.voxel_down_sample(resolution)
-
-        # determine visibility from distance and occupancy querries
-        query_points = o3d.core.Tensor(np.asarray(pcd.points), dtype=o3d.core.Dtype.Float32)
-        unsigned_distance = scene.compute_distance(query_points)
-        occupancy = scene.compute_occupancy(query_points)
-        indices=np.where((unsigned_distance.numpy() >=0.5*resolution) & (occupancy.numpy() ==0) )[0]     
-
-        # crop sampled point cloud to only the visible points
-        pcdCropped = pcd.select_by_index(indices)
-        pcdCropped.paint_uniform_color(colorArray[i])
-        identityPointClouds.append(pcdCropped)
-
-        #report percentage
-        percentages.append((len(pcdCropped.points)/len(pcd.points)))
-    return identityPointClouds, percentages
-
-
 def create_xy_grids (geometries:List[o3d.geometry.TriangleMesh], resolution:float=0.1, direction:str='Down')-> np.array:
     """Generates a grid of rays (x,y,z,nx,ny,nz) with a spatial resolution from a set of input meshes.\n
 
@@ -320,8 +323,6 @@ def color_pointcloud_by_height(pointcloud: o3d.geometry.PointCloud, heights, buc
     if min < -hmax:
         min = -hmax
     
-    
-    
     interval = max / buckets
     lb = 0
     ub = lb+interval
@@ -546,7 +547,6 @@ def get_scene_intersections (geometries:List[o3d.geometry.TriangleMesh],mesh1:o3
     print(distance2.shape)
 
     array=np.block([b,distance1,distance2])
-
     return array
 
 def get_rays_raycast (geometries, direction:str='Down'):
@@ -563,7 +563,6 @@ def get_rays_raycast (geometries, direction:str='Down'):
         np.array[x*y,6]: grid of arrays (x,y,z,nx,ny,nz)
     """
     rays = []
-
     for g in geometries:
         # create values
         if direction == 'Down':
@@ -581,7 +580,6 @@ def get_rays_raycast (geometries, direction:str='Down'):
             plusOne=np.array([np.ones(len(g.croppedPcdMin.points))]).T
             ray=np.float32(np.column_stack((points,zero,zero,plusOne)))
             rays.append(ray)
-        # create grid
     return rays 
 
 def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], reference:o3d.geometry.PointCloud,threshold:float=0.1)-> np.array:
@@ -611,10 +609,9 @@ def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], r
     percentages=[0.0]*len(sources)
 
     # check whether source and reference are close together to minize calculations
-    ind=gt.get_box_inliers(reference.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources])
+    ind=gmu.get_box_inliers(reference.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources])
     if not ind:
         return percentages
-    # inliersSources=[sources[i] for i in ind] 
 
     # sample o3d.geometry and create identitylist so to track the indices.
     for i,source in enumerate(sources):  
@@ -635,7 +632,7 @@ def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], r
     indentityArray=np.delete(indentityArray,0)
 
     #compute distances
-    joinedPCD=gt.join_geometries(sourcePCDs)
+    joinedPCD=gmu.join_geometries(sourcePCDs)
     distances=joinedPCD.compute_point_cloud_distance(reference)
 
     #remove distances > threshold
@@ -644,9 +641,8 @@ def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], r
         return percentages
     indexArray=[indentityArray[i] for i in ind.tolist()]
 
-    # count occurences
+    #count occurences
     unique_elements, counts_elements = np.unique(indexArray, return_counts=True)
     for i,n in enumerate(unique_elements):
         percentages[n]=counts_elements[i]/len(sourcePCDs[n].points)
-
     return percentages
