@@ -11,6 +11,7 @@ from datetime import datetime
 from typing import Tuple
 import xml.etree.ElementTree as ET
 from typing import List, Tuple
+import math
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -21,6 +22,31 @@ from mpl_toolkits.mplot3d import Axes3D
 from PIL import Image
 import cv2
 
+def image_resize(img:np.array,width:int=None,height:int=None,scale:float=0.5)->np.array:
+    """Resize an cv2 image (np.array).
+
+    Args:
+        1.img (np.array) \n
+        2.width (int, optional): width in pixels. Defaults to None.\n
+        3.height (int, optional): height in pixels. Defaults to None.\n
+        4.scale (float, optional): percentual scale. Defaults to 0.5.\n
+
+    Returns:
+        np.array: resized image.
+    """
+    if scale:
+        width = math.ceil(img.shape[1] * scale )
+        height = math.ceil(img.shape[0] * scale )
+    elif width and height:
+        width=width
+        height=height
+    dim = (width, height)
+    
+    return cv2.resize(img, dim, interpolation = cv2.INTER_AREA)
+
+def rgb2gray(rgb:np.array)->np.array:
+    return np.dot(rgb[...,:3], [0.2989, 0.5870, 0.1140])
+ 
 
 def subdivide_image(image:np.array,m:int=None,n:int=None,width:int=None,height:int=None,includeLast:bool=True)->Tuple[List[np.array],List[Tuple[int,int,int,int]]]:
     """Subdivide image into [mxn] parts.\n
@@ -38,27 +64,27 @@ def subdivide_image(image:np.array,m:int=None,n:int=None,width:int=None,height:i
         roiBounds (List[tuple(int,int,int,int)])): Boundaries of each roi (nMin,nMax,mMin,mMax)\n
     """
     #includeLast or not
-    t=None if includeLast else -1    
+    t=None if includeLast else -1 
     
     #create intervals
     if m and n:
-        intervalsWidth=ut.split_list(range(image.shape[1]),n=n)
-        intervalsHeight=ut.split_list(range(image.shape[0]),n=m)
+        rows=ut.split_list(range(image.shape[0]),n=m)
+        columns=ut.split_list(range(image.shape[1]),n=n)
     elif width and height:
-        intervalsWidth=ut.split_list(range(image.shape[1]),l=width)
-        intervalsHeight=ut.split_list(range(image.shape[0]),l=height)
+        rows=ut.split_list(range(image.shape[0]),l=height)
+        columns=ut.split_list(range(image.shape[1]),l=width)
     else:
         raise ValueError('Invalid input. Enter mxn or width and height')
     
     #extract regions -> roiList, and region boundaries -> roiBounds
     roiList=[]
     roiBounds=[]
-    for x in intervalsWidth[0:t]:
-        for y in intervalsHeight[0:t]:  
-            roiList.append(image[x[0]:x[-1],y[0]:y[-1]])  
-            roiBounds.append((x[0],x[-1],y[0],y[-1]))
+    for row in rows[0:t]: 
+        for col in columns[0:t]:       
+            roiList.append(image[row[0]:row[-1]+1,col[0]:col[-1]+1])   
+            roiBounds.append((row[0],row[-1],col[0],col[-1])) 
     return roiList,roiBounds   
-    
+
 def calibrate_camera(images, CheckerBoardPattern = (7,7), squareSize: float = 1, drawImages:bool = False):
     """Calibrates a camera and determines the intrinsic matrix and distortion coëfficients using a list of images of a chessboard pattern.
 
