@@ -1,5 +1,3 @@
-import copy
-import math
 import os
 from pathlib import Path
 import shutil
@@ -9,12 +7,9 @@ from multiprocessing.sharedctypes import Value
 
 import cv2
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 import ifcopenshell
 import numpy as np
-import open3d as o3d
-import PIL
-import pye57
 import rdflib
 from geomapi.nodes import *
 from ifcopenshell.util.selector import Selector
@@ -52,7 +47,7 @@ class TestNode(unittest.TestCase):
         cls.ifc1=ifcopenshell.open(str(cls.ifcPath1))   
         cls.ifcElement1= cls.ifc1.by_guid('0KysUSO6T3_gOJKtAiUE7d')
         cls.path1=cls.path / 'BIM' / "Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d.ply"
-        cls.mesh1=gt.ifc_to_mesh(cls.ifcElement1)
+        cls.mesh1=gmu.ifc_to_mesh(cls.ifcElement1)
         cls.subject1=next(s for s in cls.bimGraph1.subjects(RDF.type) if "file:///Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d" in s.toPython())
         
         #IFC2 (IfcSite)
@@ -62,7 +57,7 @@ class TestNode(unittest.TestCase):
         cls.ifc2=ifcopenshell.open(str(cls.ifcPath2))   
         cls.ifcElement2= cls.ifc2.by_guid('3dzlFaOIb0bx0z6uxD96Sz')
         cls.path2=cls.path / 'BIM' / "BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz.ply"
-        cls.mesh2=gt.ifc_to_mesh(cls.ifcElement2) 
+        cls.mesh2=gmu.ifc_to_mesh(cls.ifcElement2) 
         cls.subject2=next(s for s in cls.bimGraph2.subjects(RDF.type) if "file:///BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz" in s.toPython())
         
         #IFC3 (IfcSlab)
@@ -72,7 +67,7 @@ class TestNode(unittest.TestCase):
         cls.ifc3=ifcopenshell.open(str(cls.ifcPath3))   
         cls.ifcElement3= cls.ifc3.by_guid('3fuhig3Pv7AexdYIkSgcdp')
         cls.path3= cls.path / 'BIM' / "174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp.ply"
-        cls.mesh3=gt.ifc_to_mesh(cls.ifcElement3) 
+        cls.mesh3=gmu.ifc_to_mesh(cls.ifcElement3) 
         cls.subject3=next(s for s in cls.bimGraph3.subjects(RDF.type) if "file:///174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp" in s.toPython())
         
         #IFC4 (IfcDoor)
@@ -82,7 +77,7 @@ class TestNode(unittest.TestCase):
         cls.ifc4=ifcopenshell.open(str(cls.ifcPath4))   
         cls.ifcElement4= cls.ifc4.by_guid('3M6cRe8S51TfU811R8bxHi')
         cls.path4= cls.path / 'BIM' / "2RA_doors_single_omlijsting_omlijsting_-_85_x_217_1855492_3M6cRe8S51TfU811R8bxHi.ply"
-        cls.mesh4=gt.ifc_to_mesh(cls.ifcElement4) 
+        cls.mesh4=gmu.ifc_to_mesh(cls.ifcElement4) 
         cls.subject4=next(s for s in cls.bimGraph4.subjects(RDF.type) if "file:///2RA_doors_single_omlijsting_omlijsting_-_85_x_217_1855492_3M6cRe8S51TfU811R8bxHi" in s.toPython())
        
         #RESOURCES
@@ -200,7 +195,7 @@ class TestNode(unittest.TestCase):
         self.assertEqual(node.faceCount,len(self.mesh3.triangles))
 
     def test_bimnode_creation_from_trimesh(self):
-        myTrimesh=gt.mesh_to_trimesh(self.mesh2)
+        myTrimesh=gmu.mesh_to_trimesh(self.mesh2)
         node= BIMNode(resource=myTrimesh)
         self.assertEqual(node.faceCount,len(self.mesh2.triangles))
 
