@@ -1,3 +1,4 @@
+from pathlib import Path
 import unittest
 import numpy as np
 import open3d as o3d
@@ -25,9 +26,11 @@ class TestCompletionTools(unittest.TestCase):
         #execute once before all tests
         print('-----------------Setup Class----------------------')
         st = time.time()
-        cls.path=os.path.join(os.getcwd(), "test","testfiles") #os.pardir, 
+        cls.path= Path.cwd() / "test" / "testfiles" 
        
         # Import 3d models
+        cls.old_state = o3d.io.read_triangle_mesh(str(cls.path / "MESH" / "old_state.obj"))
+        cls.new_state = o3d.io.read_triangle_mesh(str(cls.path / "MESH" / "new_state.obj"))
    
         et = time.time()
         print("startup time: "+str(et - st))
@@ -55,10 +58,8 @@ class TestCompletionTools(unittest.TestCase):
 
     # Testing the Utils
 
-    def test_tools(self):
-        self.assertEqual(1,1)
-
-
+    def test_combine_geometry(self):
+        newGeo = ct.combine_geometry(self.old_state, self.new_state)
 
 if __name__ == '__main__':
     unittest.main()
